@@ -15,38 +15,36 @@ class Assertions(object):
     registered_assertions = {}
 
     @classmethod
-    def assertion(cls, method):
+    def assertion(cls, func):
         '''Function decorator.  Provides lower-level control for custom
         assertions than `@Assertions.create_assertions`.
 
-        If you need more control over your error message, or your assertion
-        doesn’t have a corresponding `not_`, use this decorator and
-        raise a `AssertionError`.
+        This decorator is preferable over `@Assertions.create_assertions` 
+        if you need to fine-tune your error message, or if your assertion 
+        doesn’t have a corresponding `not_`. 
+        
+        Unlike `@Assertions.create_assertions`, functions decorated with
+        this shouldn’t return a boolean. Instead, they should check for 
+        undesirable conditions and raise an `AssertionError` when appropriate. 
 
-        By raising a `AssertionError`, you get the benefit of highlighting
-        the important values when your tests are broken.
-
-        If you still just wanna raise an `AssertionError` like old times,
-        that’s supported, too.
-
-        It’s recommended to always declare both the assertion and the `not_`
-        assertion (if applicable), so they can be used like this:
+        Whenever possible, you should declare both the normal assertion as well
+        as a `not_` counterpart, so they can be used like this:
 
             expect(5).to_be_a_positive_integer()
             expect(-3).Not.to_be_a_positive_integer()
+            
         '''
-        def method_name(*args, **kw):
-            method(*args, **kw)
+        def func_name(*args, **kw):
+            func(*args, **kw)
 
-        def exec_assertion(*args, **kw):
-            return method_name(*args, **kw)
+        def test_assertion(*args, **kw):
+            return func_name(*args, **kw)
 
-        Assertions.registered_assertions[method.__name__] = exec_assertion
-
-        return method_name
+        cls.registered_assertions[func.__name__] = test_assertion
+        return func_name
 
     @classmethod
-    def create_assertions(cls, method):
+    def create_assertions(cls, func):
         '''Function decorator.  Use to create custom assertions for your
         tests.
         ''' '''
@@ -73,31 +71,32 @@ class Assertions(object):
         …will report:
 
             Expected topic(4) not to be greater than 3.
+            
         '''
-        humanized_method_name = re.sub(r'_+', ' ', method.__name__)
+        humanized_name = re.sub(r'_+', ' ', func.__name__)
 
-        def _assertion_msg(assertion_clause=None, *args):
-            raw_msg = 'Expected topic({{0}}) {assertion_clause}'.format(
+        def _assertion_msg(assertion_clause, *args):
+            raw_msg = 'Expected topic({{0!r}}) {assertion_clause}'.format(
                 assertion_clause=assertion_clause)
             if len(args) is 2:
-                raw_msg += ' {1}'
+                raw_msg += ' {1!r}'
             return raw_msg
 
-        def exec_assertion(*args):
-            raw_msg = _assertion_msg(humanized_method_name, *args)
-            if not method(*args):
+        def test_assertion(*args):
+            raw_msg = _assertion_msg(humanized_name, *args)
+            if not func(*args):
                 raise AssertionError(raw_msg.format(*args))
 
-        def exec_not_assertion(*args):
-            raw_msg = _assertion_msg('not {0}'.format(humanized_method_name), *args)
-            if method(*args):
+        def test_not_assertion(*args):
+            raw_msg = _assertion_msg('not {0}'.format(humanized_name), *args)
+            if func(*args):
                 raise AssertionError(raw_msg.format(*args))
 
-        Assertions.registered_assertions[method.__name__] = exec_assertion
-        Assertions.registered_assertions['not_{method_name}'.format(method_name=method.__name__)] = exec_not_assertion
+        cls.registered_assertions[func.__name__] = test_assertion
+        cls.registered_assertions['not_{method_name}'.format(method_name=func.__name__)] = test_not_assertion
 
         def wrapper(*args, **kw):
-            return method(*args, **kw)
+            return func(*args, **kw)
 
         return wrapper
 
@@ -122,16 +121,13 @@ class Expect(object):
         if name == 'Not':
             self.not_assert = not self.not_assert
             return self
-
-        # update `not_` assertions
-        if self.not_assert:
-            method_name = 'not_{name}'.format(name=name)
-        else:
-            method_name = name
+        
+        # determine whether assertion is of "not" form
+        method_name = 'not_{name}'.format(name=name) if self.not_assert  else name
 
         # check for unregistered assertions
         if method_name not in Assertions.registered_assertions:
-            raise AttributeError('Assertion {method_name} was not found!'.format(method_name=method_name))
+            raise AttributeError('Assertion "{method_name}" was not found!'.format(method_name=method_name))
 
         # if program gets this far, then it’s time to perform the assertion. (...FINALLY! ;D)
         def assert_topic(*args, **kw):
